==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebActiveNodeChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveNodeChangeEventArgsDetailDescriptionMetadata } from "./WebActiveNodeChangeEventArgsDetailDescriptionMetadata";
import { WebActiveNodeChangeEventArgsDescription } from "./WebActiveNodeChangeEventArgsDescription";
/**
 * @hidden
 */
var WebActiveNodeChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveNodeChangeEventArgsDescriptionMetadata, _super);
    function WebActiveNodeChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActiveNodeChangeEventArgsDescriptionMetadata.b = function (a) {
        if (WebActiveNodeChangeEventArgsDescriptionMetadata.a == null) {
            WebActiveNodeChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActiveNodeChangeEventArgsDescriptionMetadata.c(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebActiveNodeChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
        WebActiveNodeChangeEventArgsDetailDescriptionMetadata.d(a);
    };
    WebActiveNodeChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActiveNodeChangeEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebActiveNodeChangeEventArgsDetail");
    };
    WebActiveNodeChangeEventArgsDescriptionMetadata.d = function (a) {
        WebActiveNodeChangeEventArgsDescriptionMetadata.b(a);
        a.aa("WebActiveNodeChangeEventArgs", function () { return new WebActiveNodeChangeEventArgsDescription(); });
        a.z("WebActiveNodeChangeEventArgs", WebActiveNodeChangeEventArgsDescriptionMetadata.a);
    };
    WebActiveNodeChangeEventArgsDescriptionMetadata.$t = markType(WebActiveNodeChangeEventArgsDescriptionMetadata, 'WebActiveNodeChangeEventArgsDescriptionMetadata');
    WebActiveNodeChangeEventArgsDescriptionMetadata.a = null;
    return WebActiveNodeChangeEventArgsDescriptionMetadata;
}(Base));
export { WebActiveNodeChangeEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebActiveNodeChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveNodeChangeEventArgsDetailDescriptionMetadata } from "./WebActiveNodeChangeEventArgsDetailDescriptionMetadata";
import { WebActiveNodeChangeEventArgsDescription } from "./WebActiveNodeChangeEventArgsDescription";
/**
 * @hidden
 */
var WebActiveNodeChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveNodeChangeEventArgsDescriptionMetadata, _super);
    function WebActiveNodeChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActiveNodeChangeEventArgsDescriptionMetadata.b = function (a) {
        if (WebActiveNodeChangeEventArgsDescriptionMetadata.a == null) {
            WebActiveNodeChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActiveNodeChangeEventArgsDescriptionMetadata.c(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebActiveNodeChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
        WebActiveNodeChangeEventArgsDetailDescriptionMetadata.d(a);
    };
    WebActiveNodeChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActiveNodeChangeEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebActiveNodeChangeEventArgsDetail");
    };
    WebActiveNodeChangeEventArgsDescriptionMetadata.d = function (a) {
        WebActiveNodeChangeEventArgsDescriptionMetadata.b(a);
        a.ac("WebActiveNodeChangeEventArgs", function () { return new WebActiveNodeChangeEventArgsDescription(); });
        a.ab("WebActiveNodeChangeEventArgs", WebActiveNodeChangeEventArgsDescriptionMetadata.a);
    };
    WebActiveNodeChangeEventArgsDescriptionMetadata.$t = markType(WebActiveNodeChangeEventArgsDescriptionMetadata, 'WebActiveNodeChangeEventArgsDescriptionMetadata');
    WebActiveNodeChangeEventArgsDescriptionMetadata.a = null;
    return WebActiveNodeChangeEventArgsDescriptionMetadata;
}(Base));
export { WebActiveNodeChangeEventArgsDescriptionMetadata };
